"""
Utility and application modules for ISR (and CSR) data processing and modeling

where:

    ISR=Incoherent Scatter Radar
    CSR=smaller ionospheric/atmospheric radars than ISR's that can only detect
stronger coherent scatter than minimal level ionospheric incoherent scatter


Try "ISRpy. TAB" in ipython for module methods and submodules...

-readpack and beampack provides data read and target positioning
routines for a collection of ISR's and CSR's.

-pyigrf is a packet for geomagnetic vector field computataions based on the
IGRF model.

-kmltools provides routines for placing radar beam and data maps in Google Earth.

-enoise is spectral noise level estimator based on Hildebrand-Sekhon algorithm.

"""
from . import readpack
from . import beampack
from . import enoise
from .pyigrf import pyigrf

# from . import kmltools # needs to be fixed

igrf = pyigrf() # instantiating with the latest IGRF coefficients

__all__=['readpack','beampack','kmltools','enoise', 'igrf']
